import requests
from .exceptions import GraphqlException


class GraphqlService:
    def __init__(self, shop_domain: str, access_token: str):
        if not shop_domain or not access_token:
            raise ValueError("Shop domain and access token must be provided.")

        self.shop_domain = shop_domain
        self.access_token = access_token
        self.base_url = f"https://{self.shop_domain}/admin/api/2025-01/graphql.json"
        self.headers = {
            "X-Shopify-Access-Token": self.access_token,
            "Content-Type": "application/json",
        }

    def graphql_query_thalia(self, query: str, variables: dict = None) -> dict:
        payload = {
            "query": query,
            "variables": variables or {}
        }

        try:
            response = requests.post(self.base_url, headers=self.headers, json=payload)
            response.raise_for_status()
            return response.json()
        except requests.exceptions.HTTPError as http_err:
            try:
                error_response = response.json()
                errors = error_response.get("errors", ["Unknown error"])
            except Exception:
                errors = ["Unknown error during error parsing"]

            raise GraphqlException(
                "Shopify API request failed",
                response.status_code,
                errors,
                http_err
            )
        except requests.exceptions.RequestException as e:
            raise GraphqlException("Network error occurred", 0, ["Network error"], e)



class GraphqlException(Exception):
    def __init__(self, message, code, errors, original_exception):
        super().__init__(message)
        self.code = code
        self.errors = errors
        self.original_exception = original_exception

    def __str__(self):
        return f"{self.args[0]} (Code: {self.code}) | Errors: {self.errors}"


from setuptools import setup, find_packages

setup(
    name="py-shopify-graphql",
    version="0.1.0",
    description="A Python client for making Shopify GraphQL API requests",
    author="Pawan More",
    author_email="hello@pawanmore.com",
    url="https://github.com/pawan1793/py-shopify-graphql-client",
    packages=find_packages(),
    install_requires=[
        "requests>=2.25.0"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires=">=3.7",
)